# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDataPumpParameters(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Optional parameters for Data Pump Export and Import. Refer to `Configuring Optional Initial Load Advanced Settings`__
    If an empty object is specified, the stored Data Pump Parameter details will be removed.

    __ https://docs-uat.us.oracle.com/en/cloud/paas/database-migration/dmsus/working-migration-resources.html#GUID-24BD3054-FDF8-48FF-8492-636C1D4B71ED
    """

    #: A constant which can be used with the estimate property of a UpdateDataPumpParameters.
    #: This constant has a value of "BLOCKS"
    ESTIMATE_BLOCKS = "BLOCKS"

    #: A constant which can be used with the estimate property of a UpdateDataPumpParameters.
    #: This constant has a value of "STATISTICS"
    ESTIMATE_STATISTICS = "STATISTICS"

    #: A constant which can be used with the table_exists_action property of a UpdateDataPumpParameters.
    #: This constant has a value of "TRUNCATE"
    TABLE_EXISTS_ACTION_TRUNCATE = "TRUNCATE"

    #: A constant which can be used with the table_exists_action property of a UpdateDataPumpParameters.
    #: This constant has a value of "REPLACE"
    TABLE_EXISTS_ACTION_REPLACE = "REPLACE"

    #: A constant which can be used with the table_exists_action property of a UpdateDataPumpParameters.
    #: This constant has a value of "APPEND"
    TABLE_EXISTS_ACTION_APPEND = "APPEND"

    #: A constant which can be used with the table_exists_action property of a UpdateDataPumpParameters.
    #: This constant has a value of "SKIP"
    TABLE_EXISTS_ACTION_SKIP = "SKIP"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDataPumpParameters object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_cluster:
            The value to assign to the is_cluster property of this UpdateDataPumpParameters.
        :type is_cluster: bool

        :param estimate:
            The value to assign to the estimate property of this UpdateDataPumpParameters.
            Allowed values for this property are: "BLOCKS", "STATISTICS"
        :type estimate: str

        :param table_exists_action:
            The value to assign to the table_exists_action property of this UpdateDataPumpParameters.
            Allowed values for this property are: "TRUNCATE", "REPLACE", "APPEND", "SKIP"
        :type table_exists_action: str

        :param exclude_parameters:
            The value to assign to the exclude_parameters property of this UpdateDataPumpParameters.
        :type exclude_parameters: list[oci.database_migration.models.DataPumpExcludeParameters]

        :param import_parallelism_degree:
            The value to assign to the import_parallelism_degree property of this UpdateDataPumpParameters.
        :type import_parallelism_degree: int

        :param export_parallelism_degree:
            The value to assign to the export_parallelism_degree property of this UpdateDataPumpParameters.
        :type export_parallelism_degree: int

        """
        self.swagger_types = {
            'is_cluster': 'bool',
            'estimate': 'str',
            'table_exists_action': 'str',
            'exclude_parameters': 'list[DataPumpExcludeParameters]',
            'import_parallelism_degree': 'int',
            'export_parallelism_degree': 'int'
        }

        self.attribute_map = {
            'is_cluster': 'isCluster',
            'estimate': 'estimate',
            'table_exists_action': 'tableExistsAction',
            'exclude_parameters': 'excludeParameters',
            'import_parallelism_degree': 'importParallelismDegree',
            'export_parallelism_degree': 'exportParallelismDegree'
        }

        self._is_cluster = None
        self._estimate = None
        self._table_exists_action = None
        self._exclude_parameters = None
        self._import_parallelism_degree = None
        self._export_parallelism_degree = None

    @property
    def is_cluster(self):
        """
        Gets the is_cluster of this UpdateDataPumpParameters.
        Set to false to force Data Pump worker processes to run on one instance.


        :return: The is_cluster of this UpdateDataPumpParameters.
        :rtype: bool
        """
        return self._is_cluster

    @is_cluster.setter
    def is_cluster(self, is_cluster):
        """
        Sets the is_cluster of this UpdateDataPumpParameters.
        Set to false to force Data Pump worker processes to run on one instance.


        :param is_cluster: The is_cluster of this UpdateDataPumpParameters.
        :type: bool
        """
        self._is_cluster = is_cluster

    @property
    def estimate(self):
        """
        Gets the estimate of this UpdateDataPumpParameters.
        Estimate size of dumps that will be generated.

        Allowed values for this property are: "BLOCKS", "STATISTICS"


        :return: The estimate of this UpdateDataPumpParameters.
        :rtype: str
        """
        return self._estimate

    @estimate.setter
    def estimate(self, estimate):
        """
        Sets the estimate of this UpdateDataPumpParameters.
        Estimate size of dumps that will be generated.


        :param estimate: The estimate of this UpdateDataPumpParameters.
        :type: str
        """
        allowed_values = ["BLOCKS", "STATISTICS"]
        if not value_allowed_none_or_none_sentinel(estimate, allowed_values):
            raise ValueError(
                "Invalid value for `estimate`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._estimate = estimate

    @property
    def table_exists_action(self):
        """
        Gets the table_exists_action of this UpdateDataPumpParameters.
        IMPORT: Specifies the action to be performed when data is loaded into a preexisting table.

        Allowed values for this property are: "TRUNCATE", "REPLACE", "APPEND", "SKIP"


        :return: The table_exists_action of this UpdateDataPumpParameters.
        :rtype: str
        """
        return self._table_exists_action

    @table_exists_action.setter
    def table_exists_action(self, table_exists_action):
        """
        Sets the table_exists_action of this UpdateDataPumpParameters.
        IMPORT: Specifies the action to be performed when data is loaded into a preexisting table.


        :param table_exists_action: The table_exists_action of this UpdateDataPumpParameters.
        :type: str
        """
        allowed_values = ["TRUNCATE", "REPLACE", "APPEND", "SKIP"]
        if not value_allowed_none_or_none_sentinel(table_exists_action, allowed_values):
            raise ValueError(
                "Invalid value for `table_exists_action`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._table_exists_action = table_exists_action

    @property
    def exclude_parameters(self):
        """
        Gets the exclude_parameters of this UpdateDataPumpParameters.
        Exclude paratemers for Export and Import. If specified, the stored list will be replaced.


        :return: The exclude_parameters of this UpdateDataPumpParameters.
        :rtype: list[oci.database_migration.models.DataPumpExcludeParameters]
        """
        return self._exclude_parameters

    @exclude_parameters.setter
    def exclude_parameters(self, exclude_parameters):
        """
        Sets the exclude_parameters of this UpdateDataPumpParameters.
        Exclude paratemers for Export and Import. If specified, the stored list will be replaced.


        :param exclude_parameters: The exclude_parameters of this UpdateDataPumpParameters.
        :type: list[oci.database_migration.models.DataPumpExcludeParameters]
        """
        self._exclude_parameters = exclude_parameters

    @property
    def import_parallelism_degree(self):
        """
        Gets the import_parallelism_degree of this UpdateDataPumpParameters.
        Maximum number of worker processes that can be used for a Data Pump Import job.
        For an Autonomous Database, ODMS will automatically query its CPU core count and set this property.


        :return: The import_parallelism_degree of this UpdateDataPumpParameters.
        :rtype: int
        """
        return self._import_parallelism_degree

    @import_parallelism_degree.setter
    def import_parallelism_degree(self, import_parallelism_degree):
        """
        Sets the import_parallelism_degree of this UpdateDataPumpParameters.
        Maximum number of worker processes that can be used for a Data Pump Import job.
        For an Autonomous Database, ODMS will automatically query its CPU core count and set this property.


        :param import_parallelism_degree: The import_parallelism_degree of this UpdateDataPumpParameters.
        :type: int
        """
        self._import_parallelism_degree = import_parallelism_degree

    @property
    def export_parallelism_degree(self):
        """
        Gets the export_parallelism_degree of this UpdateDataPumpParameters.
        Maximum number of worker processes that can be used for a Data Pump Export job.


        :return: The export_parallelism_degree of this UpdateDataPumpParameters.
        :rtype: int
        """
        return self._export_parallelism_degree

    @export_parallelism_degree.setter
    def export_parallelism_degree(self, export_parallelism_degree):
        """
        Sets the export_parallelism_degree of this UpdateDataPumpParameters.
        Maximum number of worker processes that can be used for a Data Pump Export job.


        :param export_parallelism_degree: The export_parallelism_degree of this UpdateDataPumpParameters.
        :type: int
        """
        self._export_parallelism_degree = export_parallelism_degree

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CpeDeviceShapeDetail(object):
    """
    The detailed information about a particular CPE device type. Compare with
    :class:`CpeDeviceShapeSummary`.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CpeDeviceShapeDetail object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cpe_device_shape_id:
            The value to assign to the cpe_device_shape_id property of this CpeDeviceShapeDetail.
        :type cpe_device_shape_id: str

        :param cpe_device_info:
            The value to assign to the cpe_device_info property of this CpeDeviceShapeDetail.
        :type cpe_device_info: oci.core.models.CpeDeviceInfo

        :param parameters:
            The value to assign to the parameters property of this CpeDeviceShapeDetail.
        :type parameters: list[oci.core.models.CpeDeviceConfigQuestion]

        :param template:
            The value to assign to the template property of this CpeDeviceShapeDetail.
        :type template: str

        """
        self.swagger_types = {
            'cpe_device_shape_id': 'str',
            'cpe_device_info': 'CpeDeviceInfo',
            'parameters': 'list[CpeDeviceConfigQuestion]',
            'template': 'str'
        }

        self.attribute_map = {
            'cpe_device_shape_id': 'cpeDeviceShapeId',
            'cpe_device_info': 'cpeDeviceInfo',
            'parameters': 'parameters',
            'template': 'template'
        }

        self._cpe_device_shape_id = None
        self._cpe_device_info = None
        self._parameters = None
        self._template = None

    @property
    def cpe_device_shape_id(self):
        """
        Gets the cpe_device_shape_id of this CpeDeviceShapeDetail.
        The `OCID`__ of the CPE device shape.
        This value uniquely identifies the type of CPE device.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The cpe_device_shape_id of this CpeDeviceShapeDetail.
        :rtype: str
        """
        return self._cpe_device_shape_id

    @cpe_device_shape_id.setter
    def cpe_device_shape_id(self, cpe_device_shape_id):
        """
        Sets the cpe_device_shape_id of this CpeDeviceShapeDetail.
        The `OCID`__ of the CPE device shape.
        This value uniquely identifies the type of CPE device.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param cpe_device_shape_id: The cpe_device_shape_id of this CpeDeviceShapeDetail.
        :type: str
        """
        self._cpe_device_shape_id = cpe_device_shape_id

    @property
    def cpe_device_info(self):
        """
        Gets the cpe_device_info of this CpeDeviceShapeDetail.

        :return: The cpe_device_info of this CpeDeviceShapeDetail.
        :rtype: oci.core.models.CpeDeviceInfo
        """
        return self._cpe_device_info

    @cpe_device_info.setter
    def cpe_device_info(self, cpe_device_info):
        """
        Sets the cpe_device_info of this CpeDeviceShapeDetail.

        :param cpe_device_info: The cpe_device_info of this CpeDeviceShapeDetail.
        :type: oci.core.models.CpeDeviceInfo
        """
        self._cpe_device_info = cpe_device_info

    @property
    def parameters(self):
        """
        Gets the parameters of this CpeDeviceShapeDetail.
        For certain CPE devices types, the customer can provide answers to
        questions that are specific to the device type. This attribute contains
        a list of those questions. The Networking service merges the answers with
        other information and renders a set of CPE configuration content. To
        provide the answers, use
        :func:`update_tunnel_cpe_device_config`.


        :return: The parameters of this CpeDeviceShapeDetail.
        :rtype: list[oci.core.models.CpeDeviceConfigQuestion]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this CpeDeviceShapeDetail.
        For certain CPE devices types, the customer can provide answers to
        questions that are specific to the device type. This attribute contains
        a list of those questions. The Networking service merges the answers with
        other information and renders a set of CPE configuration content. To
        provide the answers, use
        :func:`update_tunnel_cpe_device_config`.


        :param parameters: The parameters of this CpeDeviceShapeDetail.
        :type: list[oci.core.models.CpeDeviceConfigQuestion]
        """
        self._parameters = parameters

    @property
    def template(self):
        """
        Gets the template of this CpeDeviceShapeDetail.
        A template of CPE device configuration information that will be merged with the customer's
        answers to the questions to render the final CPE device configuration content. Also see:

          * :func:`get_cpe_device_config_content`
          * :func:`get_ipsec_cpe_device_config_content`
          * :func:`get_tunnel_cpe_device_config_content`


        :return: The template of this CpeDeviceShapeDetail.
        :rtype: str
        """
        return self._template

    @template.setter
    def template(self, template):
        """
        Sets the template of this CpeDeviceShapeDetail.
        A template of CPE device configuration information that will be merged with the customer's
        answers to the questions to render the final CPE device configuration content. Also see:

          * :func:`get_cpe_device_config_content`
          * :func:`get_ipsec_cpe_device_config_content`
          * :func:`get_tunnel_cpe_device_config_content`


        :param template: The template of this CpeDeviceShapeDetail.
        :type: str
        """
        self._template = template

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseStorageAggregateMetrics(object):
    """
    The database storage metric values.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseStorageAggregateMetrics object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param storage_allocated:
            The value to assign to the storage_allocated property of this DatabaseStorageAggregateMetrics.
        :type storage_allocated: oci.database_management.models.MetricDataPoint

        :param storage_used:
            The value to assign to the storage_used property of this DatabaseStorageAggregateMetrics.
        :type storage_used: oci.database_management.models.MetricDataPoint

        :param storage_used_by_table_space:
            The value to assign to the storage_used_by_table_space property of this DatabaseStorageAggregateMetrics.
        :type storage_used_by_table_space: list[oci.database_management.models.MetricDataPoint]

        """
        self.swagger_types = {
            'storage_allocated': 'MetricDataPoint',
            'storage_used': 'MetricDataPoint',
            'storage_used_by_table_space': 'list[MetricDataPoint]'
        }

        self.attribute_map = {
            'storage_allocated': 'storageAllocated',
            'storage_used': 'storageUsed',
            'storage_used_by_table_space': 'storageUsedByTableSpace'
        }

        self._storage_allocated = None
        self._storage_used = None
        self._storage_used_by_table_space = None

    @property
    def storage_allocated(self):
        """
        Gets the storage_allocated of this DatabaseStorageAggregateMetrics.

        :return: The storage_allocated of this DatabaseStorageAggregateMetrics.
        :rtype: oci.database_management.models.MetricDataPoint
        """
        return self._storage_allocated

    @storage_allocated.setter
    def storage_allocated(self, storage_allocated):
        """
        Sets the storage_allocated of this DatabaseStorageAggregateMetrics.

        :param storage_allocated: The storage_allocated of this DatabaseStorageAggregateMetrics.
        :type: oci.database_management.models.MetricDataPoint
        """
        self._storage_allocated = storage_allocated

    @property
    def storage_used(self):
        """
        Gets the storage_used of this DatabaseStorageAggregateMetrics.

        :return: The storage_used of this DatabaseStorageAggregateMetrics.
        :rtype: oci.database_management.models.MetricDataPoint
        """
        return self._storage_used

    @storage_used.setter
    def storage_used(self, storage_used):
        """
        Sets the storage_used of this DatabaseStorageAggregateMetrics.

        :param storage_used: The storage_used of this DatabaseStorageAggregateMetrics.
        :type: oci.database_management.models.MetricDataPoint
        """
        self._storage_used = storage_used

    @property
    def storage_used_by_table_space(self):
        """
        Gets the storage_used_by_table_space of this DatabaseStorageAggregateMetrics.
        A list of the storage metrics grouped by TableSpace for a specific database.


        :return: The storage_used_by_table_space of this DatabaseStorageAggregateMetrics.
        :rtype: list[oci.database_management.models.MetricDataPoint]
        """
        return self._storage_used_by_table_space

    @storage_used_by_table_space.setter
    def storage_used_by_table_space(self, storage_used_by_table_space):
        """
        Sets the storage_used_by_table_space of this DatabaseStorageAggregateMetrics.
        A list of the storage metrics grouped by TableSpace for a specific database.


        :param storage_used_by_table_space: The storage_used_by_table_space of this DatabaseStorageAggregateMetrics.
        :type: list[oci.database_management.models.MetricDataPoint]
        """
        self._storage_used_by_table_space = storage_used_by_table_space

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class ArtifactsClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.artifacts.ArtifactsClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new ArtifactsClientCompositeOperations object

        :param ArtifactsClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def create_container_repository_and_wait_for_state(self, create_container_repository_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.create_container_repository` and waits for the :py:class:`~oci.artifacts.models.ContainerRepository` acted upon
        to enter the given state(s).

        :param oci.artifacts.models.CreateContainerRepositoryDetails create_container_repository_details: (required)
            Create container repository details.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.ContainerRepository.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.create_container_repository`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_container_repository(create_container_repository_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_container_repository(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_repository_and_wait_for_state(self, create_repository_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.create_repository` and waits for the :py:class:`~oci.artifacts.models.Repository` acted upon
        to enter the given state(s).

        :param oci.artifacts.models.CreateRepositoryDetails create_repository_details: (required)
            Creates a new repository for storing artifacts.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.Repository.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.create_repository`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_repository(create_repository_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_repository(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_container_image_and_wait_for_state(self, image_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.delete_container_image` and waits for the :py:class:`~oci.artifacts.models.ContainerImage` acted upon
        to enter the given state(s).

        :param str image_id: (required)
            The `OCID`__ of the container image.

            Example: `ocid1.containerimage.oc1..exampleuniqueID`

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.ContainerImage.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.delete_container_image`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        initial_get_result = self.client.get_container_image(image_id)
        operation_result = None
        try:
            operation_result = self.client.delete_container_image(image_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]

        try:
            waiter_result = oci.wait_until(
                self.client,
                initial_get_result,
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                succeed_on_not_found=True,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_container_repository_and_wait_for_state(self, repository_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.delete_container_repository` and waits for the :py:class:`~oci.artifacts.models.ContainerRepository` acted upon
        to enter the given state(s).

        :param str repository_id: (required)
            The `OCID`__ of the container repository.

            Example: `ocid1.containerrepo.oc1..exampleuniqueID`

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.ContainerRepository.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.delete_container_repository`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        initial_get_result = self.client.get_container_repository(repository_id)
        operation_result = None
        try:
            operation_result = self.client.delete_container_repository(repository_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]

        try:
            waiter_result = oci.wait_until(
                self.client,
                initial_get_result,
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                succeed_on_not_found=True,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_generic_artifact_and_wait_for_state(self, artifact_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.delete_generic_artifact` and waits for the :py:class:`~oci.artifacts.models.GenericArtifact` acted upon
        to enter the given state(s).

        :param str artifact_id: (required)
            The `OCID`__ of the artifact.

            Example: `ocid1.genericartifact.oc1..exampleuniqueID`

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.GenericArtifact.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.delete_generic_artifact`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        initial_get_result = self.client.get_generic_artifact(artifact_id)
        operation_result = None
        try:
            operation_result = self.client.delete_generic_artifact(artifact_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]

        try:
            waiter_result = oci.wait_until(
                self.client,
                initial_get_result,
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                succeed_on_not_found=True,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_repository_and_wait_for_state(self, repository_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.delete_repository` and waits for the :py:class:`~oci.artifacts.models.Repository` acted upon
        to enter the given state(s).

        :param str repository_id: (required)
            The `OCID`__ of the repository.

            Example: `ocid1.artifactrepository.oc1..exampleuniqueID`

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.Repository.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.delete_repository`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        initial_get_result = self.client.get_repository(repository_id)
        operation_result = None
        try:
            operation_result = self.client.delete_repository(repository_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]

        try:
            waiter_result = oci.wait_until(
                self.client,
                initial_get_result,
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                succeed_on_not_found=True,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def remove_container_version_and_wait_for_state(self, image_id, remove_container_version_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.remove_container_version` and waits for the :py:class:`~oci.artifacts.models.ContainerImage` acted upon
        to enter the given state(s).

        :param str image_id: (required)
            The `OCID`__ of the container image.

            Example: `ocid1.containerimage.oc1..exampleuniqueID`

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.artifacts.models.RemoveContainerVersionDetails remove_container_version_details: (required)
            Remove version details.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.ContainerImage.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.remove_container_version`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.remove_container_version(image_id, remove_container_version_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_container_image(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def restore_container_image_and_wait_for_state(self, image_id, restore_container_image_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.restore_container_image` and waits for the :py:class:`~oci.artifacts.models.ContainerImage` acted upon
        to enter the given state(s).

        :param str image_id: (required)
            The `OCID`__ of the container image.

            Example: `ocid1.containerimage.oc1..exampleuniqueID`

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.artifacts.models.RestoreContainerImageDetails restore_container_image_details: (required)
            Restore container image details.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.ContainerImage.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.restore_container_image`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.restore_container_image(image_id, restore_container_image_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_container_image(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_container_repository_and_wait_for_state(self, repository_id, update_container_repository_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.update_container_repository` and waits for the :py:class:`~oci.artifacts.models.ContainerRepository` acted upon
        to enter the given state(s).

        :param str repository_id: (required)
            The `OCID`__ of the container repository.

            Example: `ocid1.containerrepo.oc1..exampleuniqueID`

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.artifacts.models.UpdateContainerRepositoryDetails update_container_repository_details: (required)
            Update container repository details.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.ContainerRepository.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.update_container_repository`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_container_repository(repository_id, update_container_repository_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_container_repository(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_generic_artifact_and_wait_for_state(self, artifact_id, update_generic_artifact_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.update_generic_artifact` and waits for the :py:class:`~oci.artifacts.models.GenericArtifact` acted upon
        to enter the given state(s).

        :param str artifact_id: (required)
            The `OCID`__ of the artifact.

            Example: `ocid1.genericartifact.oc1..exampleuniqueID`

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.artifacts.models.UpdateGenericArtifactDetails update_generic_artifact_details: (required)
            Updates the artifact with the specified `OCID`__. You can only update the tags of an artifact.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.GenericArtifact.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.update_generic_artifact`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_generic_artifact(artifact_id, update_generic_artifact_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_generic_artifact(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_repository_and_wait_for_state(self, repository_id, update_repository_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.artifacts.ArtifactsClient.update_repository` and waits for the :py:class:`~oci.artifacts.models.Repository` acted upon
        to enter the given state(s).

        :param str repository_id: (required)
            The `OCID`__ of the repository.

            Example: `ocid1.artifactrepository.oc1..exampleuniqueID`

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.artifacts.models.UpdateRepositoryDetails update_repository_details: (required)
            Updates the properties of a repository.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.artifacts.models.Repository.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.artifacts.ArtifactsClient.update_repository`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_repository(repository_id, update_repository_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_repository(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScriptParameterInfo(object):
    """
    Information about script parameters.
    isOverwritten specifies that the default parameter present in the script content is overwritten.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ScriptParameterInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param script_parameter:
            The value to assign to the script_parameter property of this ScriptParameterInfo.
        :type script_parameter: oci.apm_synthetics.models.ScriptParameter

        :param is_overwritten:
            The value to assign to the is_overwritten property of this ScriptParameterInfo.
        :type is_overwritten: bool

        """
        self.swagger_types = {
            'script_parameter': 'ScriptParameter',
            'is_overwritten': 'bool'
        }

        self.attribute_map = {
            'script_parameter': 'scriptParameter',
            'is_overwritten': 'isOverwritten'
        }

        self._script_parameter = None
        self._is_overwritten = None

    @property
    def script_parameter(self):
        """
        **[Required]** Gets the script_parameter of this ScriptParameterInfo.

        :return: The script_parameter of this ScriptParameterInfo.
        :rtype: oci.apm_synthetics.models.ScriptParameter
        """
        return self._script_parameter

    @script_parameter.setter
    def script_parameter(self, script_parameter):
        """
        Sets the script_parameter of this ScriptParameterInfo.

        :param script_parameter: The script_parameter of this ScriptParameterInfo.
        :type: oci.apm_synthetics.models.ScriptParameter
        """
        self._script_parameter = script_parameter

    @property
    def is_overwritten(self):
        """
        **[Required]** Gets the is_overwritten of this ScriptParameterInfo.
        If parameter value is default or overwritten.


        :return: The is_overwritten of this ScriptParameterInfo.
        :rtype: bool
        """
        return self._is_overwritten

    @is_overwritten.setter
    def is_overwritten(self, is_overwritten):
        """
        Sets the is_overwritten of this ScriptParameterInfo.
        If parameter value is default or overwritten.


        :param is_overwritten: The is_overwritten of this ScriptParameterInfo.
        :type: bool
        """
        self._is_overwritten = is_overwritten

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkRequestError(object):
    """
    An object returned in the event of a work request error.
    """

    #: A constant which can be used with the error_code property of a WorkRequestError.
    #: This constant has a value of "BAD_INPUT"
    ERROR_CODE_BAD_INPUT = "BAD_INPUT"

    #: A constant which can be used with the error_code property of a WorkRequestError.
    #: This constant has a value of "INTERNAL_ERROR"
    ERROR_CODE_INTERNAL_ERROR = "INTERNAL_ERROR"

    def __init__(self, **kwargs):
        """
        Initializes a new WorkRequestError object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param error_code:
            The value to assign to the error_code property of this WorkRequestError.
            Allowed values for this property are: "BAD_INPUT", "INTERNAL_ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type error_code: str

        :param message:
            The value to assign to the message property of this WorkRequestError.
        :type message: str

        """
        self.swagger_types = {
            'error_code': 'str',
            'message': 'str'
        }

        self.attribute_map = {
            'error_code': 'errorCode',
            'message': 'message'
        }

        self._error_code = None
        self._message = None

    @property
    def error_code(self):
        """
        **[Required]** Gets the error_code of this WorkRequestError.
        Allowed values for this property are: "BAD_INPUT", "INTERNAL_ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The error_code of this WorkRequestError.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this WorkRequestError.

        :param error_code: The error_code of this WorkRequestError.
        :type: str
        """
        allowed_values = ["BAD_INPUT", "INTERNAL_ERROR"]
        if not value_allowed_none_or_none_sentinel(error_code, allowed_values):
            error_code = 'UNKNOWN_ENUM_VALUE'
        self._error_code = error_code

    @property
    def message(self):
        """
        **[Required]** Gets the message of this WorkRequestError.
        A human-readable error string.


        :return: The message of this WorkRequestError.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this WorkRequestError.
        A human-readable error string.


        :param message: The message of this WorkRequestError.
        :type: str
        """
        self._message = message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProtectionSettings(object):
    """
    The settings used for protection rules.
    """

    #: A constant which can be used with the block_action property of a ProtectionSettings.
    #: This constant has a value of "SHOW_ERROR_PAGE"
    BLOCK_ACTION_SHOW_ERROR_PAGE = "SHOW_ERROR_PAGE"

    #: A constant which can be used with the block_action property of a ProtectionSettings.
    #: This constant has a value of "SET_RESPONSE_CODE"
    BLOCK_ACTION_SET_RESPONSE_CODE = "SET_RESPONSE_CODE"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "OPTIONS"
    ALLOWED_HTTP_METHODS_OPTIONS = "OPTIONS"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "GET"
    ALLOWED_HTTP_METHODS_GET = "GET"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "HEAD"
    ALLOWED_HTTP_METHODS_HEAD = "HEAD"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "POST"
    ALLOWED_HTTP_METHODS_POST = "POST"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "PUT"
    ALLOWED_HTTP_METHODS_PUT = "PUT"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "DELETE"
    ALLOWED_HTTP_METHODS_DELETE = "DELETE"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "TRACE"
    ALLOWED_HTTP_METHODS_TRACE = "TRACE"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "CONNECT"
    ALLOWED_HTTP_METHODS_CONNECT = "CONNECT"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "PATCH"
    ALLOWED_HTTP_METHODS_PATCH = "PATCH"

    #: A constant which can be used with the allowed_http_methods property of a ProtectionSettings.
    #: This constant has a value of "PROPFIND"
    ALLOWED_HTTP_METHODS_PROPFIND = "PROPFIND"

    def __init__(self, **kwargs):
        """
        Initializes a new ProtectionSettings object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param block_action:
            The value to assign to the block_action property of this ProtectionSettings.
            Allowed values for this property are: "SHOW_ERROR_PAGE", "SET_RESPONSE_CODE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type block_action: str

        :param block_response_code:
            The value to assign to the block_response_code property of this ProtectionSettings.
        :type block_response_code: int

        :param block_error_page_message:
            The value to assign to the block_error_page_message property of this ProtectionSettings.
        :type block_error_page_message: str

        :param block_error_page_code:
            The value to assign to the block_error_page_code property of this ProtectionSettings.
        :type block_error_page_code: str

        :param block_error_page_description:
            The value to assign to the block_error_page_description property of this ProtectionSettings.
        :type block_error_page_description: str

        :param max_argument_count:
            The value to assign to the max_argument_count property of this ProtectionSettings.
        :type max_argument_count: int

        :param max_name_length_per_argument:
            The value to assign to the max_name_length_per_argument property of this ProtectionSettings.
        :type max_name_length_per_argument: int

        :param max_total_name_length_of_arguments:
            The value to assign to the max_total_name_length_of_arguments property of this ProtectionSettings.
        :type max_total_name_length_of_arguments: int

        :param recommendations_period_in_days:
            The value to assign to the recommendations_period_in_days property of this ProtectionSettings.
        :type recommendations_period_in_days: int

        :param is_response_inspected:
            The value to assign to the is_response_inspected property of this ProtectionSettings.
        :type is_response_inspected: bool

        :param max_response_size_in_ki_b:
            The value to assign to the max_response_size_in_ki_b property of this ProtectionSettings.
        :type max_response_size_in_ki_b: int

        :param allowed_http_methods:
            The value to assign to the allowed_http_methods property of this ProtectionSettings.
            Allowed values for items in this list are: "OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "TRACE", "CONNECT", "PATCH", "PROPFIND", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type allowed_http_methods: list[str]

        :param media_types:
            The value to assign to the media_types property of this ProtectionSettings.
        :type media_types: list[str]

        """
        self.swagger_types = {
            'block_action': 'str',
            'block_response_code': 'int',
            'block_error_page_message': 'str',
            'block_error_page_code': 'str',
            'block_error_page_description': 'str',
            'max_argument_count': 'int',
            'max_name_length_per_argument': 'int',
            'max_total_name_length_of_arguments': 'int',
            'recommendations_period_in_days': 'int',
            'is_response_inspected': 'bool',
            'max_response_size_in_ki_b': 'int',
            'allowed_http_methods': 'list[str]',
            'media_types': 'list[str]'
        }

        self.attribute_map = {
            'block_action': 'blockAction',
            'block_response_code': 'blockResponseCode',
            'block_error_page_message': 'blockErrorPageMessage',
            'block_error_page_code': 'blockErrorPageCode',
            'block_error_page_description': 'blockErrorPageDescription',
            'max_argument_count': 'maxArgumentCount',
            'max_name_length_per_argument': 'maxNameLengthPerArgument',
            'max_total_name_length_of_arguments': 'maxTotalNameLengthOfArguments',
            'recommendations_period_in_days': 'recommendationsPeriodInDays',
            'is_response_inspected': 'isResponseInspected',
            'max_response_size_in_ki_b': 'maxResponseSizeInKiB',
            'allowed_http_methods': 'allowedHttpMethods',
            'media_types': 'mediaTypes'
        }

        self._block_action = None
        self._block_response_code = None
        self._block_error_page_message = None
        self._block_error_page_code = None
        self._block_error_page_description = None
        self._max_argument_count = None
        self._max_name_length_per_argument = None
        self._max_total_name_length_of_arguments = None
        self._recommendations_period_in_days = None
        self._is_response_inspected = None
        self._max_response_size_in_ki_b = None
        self._allowed_http_methods = None
        self._media_types = None

    @property
    def block_action(self):
        """
        Gets the block_action of this ProtectionSettings.
        If `action` is set to `BLOCK`, this specifies how the traffic is blocked when detected as malicious by a protection rule. If unspecified, defaults to `SET_RESPONSE_CODE`.

        Allowed values for this property are: "SHOW_ERROR_PAGE", "SET_RESPONSE_CODE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The block_action of this ProtectionSettings.
        :rtype: str
        """
        return self._block_action

    @block_action.setter
    def block_action(self, block_action):
        """
        Sets the block_action of this ProtectionSettings.
        If `action` is set to `BLOCK`, this specifies how the traffic is blocked when detected as malicious by a protection rule. If unspecified, defaults to `SET_RESPONSE_CODE`.


        :param block_action: The block_action of this ProtectionSettings.
        :type: str
        """
        allowed_values = ["SHOW_ERROR_PAGE", "SET_RESPONSE_CODE"]
        if not value_allowed_none_or_none_sentinel(block_action, allowed_values):
            block_action = 'UNKNOWN_ENUM_VALUE'
        self._block_action = block_action

    @property
    def block_response_code(self):
        """
        Gets the block_response_code of this ProtectionSettings.
        The response code returned when `action` is set to `BLOCK`, `blockAction` is set to `SET_RESPONSE_CODE`, and the traffic is detected as malicious by a protection rule. If unspecified, defaults to `403`. The list of available response codes: `400`, `401`, `403`, `405`, `409`, `411`, `412`, `413`, `414`, `415`, `416`, `500`, `501`, `502`, `503`, `504`, `507`.


        :return: The block_response_code of this ProtectionSettings.
        :rtype: int
        """
        return self._block_response_code

    @block_response_code.setter
    def block_response_code(self, block_response_code):
        """
        Sets the block_response_code of this ProtectionSettings.
        The response code returned when `action` is set to `BLOCK`, `blockAction` is set to `SET_RESPONSE_CODE`, and the traffic is detected as malicious by a protection rule. If unspecified, defaults to `403`. The list of available response codes: `400`, `401`, `403`, `405`, `409`, `411`, `412`, `413`, `414`, `415`, `416`, `500`, `501`, `502`, `503`, `504`, `507`.


        :param block_response_code: The block_response_code of this ProtectionSettings.
        :type: int
        """
        self._block_response_code = block_response_code

    @property
    def block_error_page_message(self):
        """
        Gets the block_error_page_message of this ProtectionSettings.
        The message to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the traffic is detected as malicious by a protection rule. If unspecified, defaults to 'Access to the website is blocked.'


        :return: The block_error_page_message of this ProtectionSettings.
        :rtype: str
        """
        return self._block_error_page_message

    @block_error_page_message.setter
    def block_error_page_message(self, block_error_page_message):
        """
        Sets the block_error_page_message of this ProtectionSettings.
        The message to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the traffic is detected as malicious by a protection rule. If unspecified, defaults to 'Access to the website is blocked.'


        :param block_error_page_message: The block_error_page_message of this ProtectionSettings.
        :type: str
        """
        self._block_error_page_message = block_error_page_message

    @property
    def block_error_page_code(self):
        """
        Gets the block_error_page_code of this ProtectionSettings.
        The error code to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the traffic is detected as malicious by a protection rule. If unspecified, defaults to `403`.


        :return: The block_error_page_code of this ProtectionSettings.
        :rtype: str
        """
        return self._block_error_page_code

    @block_error_page_code.setter
    def block_error_page_code(self, block_error_page_code):
        """
        Sets the block_error_page_code of this ProtectionSettings.
        The error code to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the traffic is detected as malicious by a protection rule. If unspecified, defaults to `403`.


        :param block_error_page_code: The block_error_page_code of this ProtectionSettings.
        :type: str
        """
        self._block_error_page_code = block_error_page_code

    @property
    def block_error_page_description(self):
        """
        Gets the block_error_page_description of this ProtectionSettings.
        The description text to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the traffic is detected as malicious by a protection rule. If unspecified, defaults to `Access blocked by website owner. Please contact support.`


        :return: The block_error_page_description of this ProtectionSettings.
        :rtype: str
        """
        return self._block_error_page_description

    @block_error_page_description.setter
    def block_error_page_description(self, block_error_page_description):
        """
        Sets the block_error_page_description of this ProtectionSettings.
        The description text to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the traffic is detected as malicious by a protection rule. If unspecified, defaults to `Access blocked by website owner. Please contact support.`


        :param block_error_page_description: The block_error_page_description of this ProtectionSettings.
        :type: str
        """
        self._block_error_page_description = block_error_page_description

    @property
    def max_argument_count(self):
        """
        Gets the max_argument_count of this ProtectionSettings.
        The maximum number of arguments allowed to be passed to your application before an action is taken. Arguements are query parameters or body parameters in a PUT or POST request. If unspecified, defaults to `255`. This setting only applies if a corresponding protection rule is enabled, such as the \"Number of Arguments Limits\" rule (key: 960335).

        Example: If `maxArgumentCount` to `2` for the Max Number of Arguments protection rule (key: 960335), the following requests would be blocked:
        `GET /myapp/path?query=one&query=two&query=three`
        `POST /myapp/path` with Body `{\"argument1\":\"one\",\"argument2\":\"two\",\"argument3\":\"three\"}`


        :return: The max_argument_count of this ProtectionSettings.
        :rtype: int
        """
        return self._max_argument_count

    @max_argument_count.setter
    def max_argument_count(self, max_argument_count):
        """
        Sets the max_argument_count of this ProtectionSettings.
        The maximum number of arguments allowed to be passed to your application before an action is taken. Arguements are query parameters or body parameters in a PUT or POST request. If unspecified, defaults to `255`. This setting only applies if a corresponding protection rule is enabled, such as the \"Number of Arguments Limits\" rule (key: 960335).

        Example: If `maxArgumentCount` to `2` for the Max Number of Arguments protection rule (key: 960335), the following requests would be blocked:
        `GET /myapp/path?query=one&query=two&query=three`
        `POST /myapp/path` with Body `{\"argument1\":\"one\",\"argument2\":\"two\",\"argument3\":\"three\"}`


        :param max_argument_count: The max_argument_count of this ProtectionSettings.
        :type: int
        """
        self._max_argument_count = max_argument_count

    @property
    def max_name_length_per_argument(self):
        """
        Gets the max_name_length_per_argument of this ProtectionSettings.
        The maximum length allowed for each argument name, in characters. Arguements are query parameters or body parameters in a PUT or POST request. If unspecified, defaults to `400`. This setting only applies if a corresponding protection rule is enabled, such as the \"Values Limits\" rule (key: 960208).


        :return: The max_name_length_per_argument of this ProtectionSettings.
        :rtype: int
        """
        return self._max_name_length_per_argument

    @max_name_length_per_argument.setter
    def max_name_length_per_argument(self, max_name_length_per_argument):
        """
        Sets the max_name_length_per_argument of this ProtectionSettings.
        The maximum length allowed for each argument name, in characters. Arguements are query parameters or body parameters in a PUT or POST request. If unspecified, defaults to `400`. This setting only applies if a corresponding protection rule is enabled, such as the \"Values Limits\" rule (key: 960208).


        :param max_name_length_per_argument: The max_name_length_per_argument of this ProtectionSettings.
        :type: int
        """
        self._max_name_length_per_argument = max_name_length_per_argument

    @property
    def max_total_name_length_of_arguments(self):
        """
        Gets the max_total_name_length_of_arguments of this ProtectionSettings.
        The maximum length allowed for the sum of the argument name and value, in characters. Arguements are query parameters or body parameters in a PUT or POST request. If unspecified, defaults to `64000`. This setting only applies if a corresponding protection rule is enabled, such as the \"Total Arguments Limits\" rule (key: 960341).


        :return: The max_total_name_length_of_arguments of this ProtectionSettings.
        :rtype: int
        """
        return self._max_total_name_length_of_arguments

    @max_total_name_length_of_arguments.setter
    def max_total_name_length_of_arguments(self, max_total_name_length_of_arguments):
        """
        Sets the max_total_name_length_of_arguments of this ProtectionSettings.
        The maximum length allowed for the sum of the argument name and value, in characters. Arguements are query parameters or body parameters in a PUT or POST request. If unspecified, defaults to `64000`. This setting only applies if a corresponding protection rule is enabled, such as the \"Total Arguments Limits\" rule (key: 960341).


        :param max_total_name_length_of_arguments: The max_total_name_length_of_arguments of this ProtectionSettings.
        :type: int
        """
        self._max_total_name_length_of_arguments = max_total_name_length_of_arguments

    @property
    def recommendations_period_in_days(self):
        """
        Gets the recommendations_period_in_days of this ProtectionSettings.
        The length of time to analyze traffic traffic, in days. After the analysis period, `WafRecommendations` will be populated. If unspecified, defaults to `10`.

        Use `GET /waasPolicies/{waasPolicyId}/wafRecommendations` to view WAF recommendations.


        :return: The recommendations_period_in_days of this ProtectionSettings.
        :rtype: int
        """
        return self._recommendations_period_in_days

    @recommendations_period_in_days.setter
    def recommendations_period_in_days(self, recommendations_period_in_days):
        """
        Sets the recommendations_period_in_days of this ProtectionSettings.
        The length of time to analyze traffic traffic, in days. After the analysis period, `WafRecommendations` will be populated. If unspecified, defaults to `10`.

        Use `GET /waasPolicies/{waasPolicyId}/wafRecommendations` to view WAF recommendations.


        :param recommendations_period_in_days: The recommendations_period_in_days of this ProtectionSettings.
        :type: int
        """
        self._recommendations_period_in_days = recommendations_period_in_days

    @property
    def is_response_inspected(self):
        """
        Gets the is_response_inspected of this ProtectionSettings.
        Inspects the response body of origin responses. Can be used to detect leakage of sensitive data. If unspecified, defaults to `false`.

        **Note:** Only origin responses with a Content-Type matching a value in `mediaTypes` will be inspected.


        :return: The is_response_inspected of this ProtectionSettings.
        :rtype: bool
        """
        return self._is_response_inspected

    @is_response_inspected.setter
    def is_response_inspected(self, is_response_inspected):
        """
        Sets the is_response_inspected of this ProtectionSettings.
        Inspects the response body of origin responses. Can be used to detect leakage of sensitive data. If unspecified, defaults to `false`.

        **Note:** Only origin responses with a Content-Type matching a value in `mediaTypes` will be inspected.


        :param is_response_inspected: The is_response_inspected of this ProtectionSettings.
        :type: bool
        """
        self._is_response_inspected = is_response_inspected

    @property
    def max_response_size_in_ki_b(self):
        """
        Gets the max_response_size_in_ki_b of this ProtectionSettings.
        The maximum response size to be fully inspected, in binary kilobytes (KiB). Anything over this limit will be partially inspected. If unspecified, defaults to `1024`.


        :return: The max_response_size_in_ki_b of this ProtectionSettings.
        :rtype: int
        """
        return self._max_response_size_in_ki_b

    @max_response_size_in_ki_b.setter
    def max_response_size_in_ki_b(self, max_response_size_in_ki_b):
        """
        Sets the max_response_size_in_ki_b of this ProtectionSettings.
        The maximum response size to be fully inspected, in binary kilobytes (KiB). Anything over this limit will be partially inspected. If unspecified, defaults to `1024`.


        :param max_response_size_in_ki_b: The max_response_size_in_ki_b of this ProtectionSettings.
        :type: int
        """
        self._max_response_size_in_ki_b = max_response_size_in_ki_b

    @property
    def allowed_http_methods(self):
        """
        Gets the allowed_http_methods of this ProtectionSettings.
        The list of allowed HTTP methods. If unspecified, default to `[OPTIONS, GET, HEAD, POST]`. This setting only applies if a corresponding protection rule is enabled, such as the \"Restrict HTTP Request Methods\" rule (key: 911100).

        Allowed values for items in this list are: "OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "TRACE", "CONNECT", "PATCH", "PROPFIND", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The allowed_http_methods of this ProtectionSettings.
        :rtype: list[str]
        """
        return self._allowed_http_methods

    @allowed_http_methods.setter
    def allowed_http_methods(self, allowed_http_methods):
        """
        Sets the allowed_http_methods of this ProtectionSettings.
        The list of allowed HTTP methods. If unspecified, default to `[OPTIONS, GET, HEAD, POST]`. This setting only applies if a corresponding protection rule is enabled, such as the \"Restrict HTTP Request Methods\" rule (key: 911100).


        :param allowed_http_methods: The allowed_http_methods of this ProtectionSettings.
        :type: list[str]
        """
        allowed_values = ["OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "TRACE", "CONNECT", "PATCH", "PROPFIND"]
        if allowed_http_methods:
            allowed_http_methods[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in allowed_http_methods]
        self._allowed_http_methods = allowed_http_methods

    @property
    def media_types(self):
        """
        Gets the media_types of this ProtectionSettings.
        The list of media types to allow for inspection, if `isResponseInspected` is enabled. Only responses with MIME types in this list will be inspected. If unspecified, defaults to `[\"text/html\", \"text/plain\", \"text/xml\"]`.

            Supported MIME types include:

            - text/html
            - text/plain
            - text/asp
            - text/css
            - text/x-script
            - application/json
            - text/webviewhtml
            - text/x-java-source
            - application/x-javascript
            - application/javascript
            - application/ecmascript
            - text/javascript
            - text/ecmascript
            - text/x-script.perl
            - text/x-script.phyton
            - application/plain
            - application/xml
            - text/xml


        :return: The media_types of this ProtectionSettings.
        :rtype: list[str]
        """
        return self._media_types

    @media_types.setter
    def media_types(self, media_types):
        """
        Sets the media_types of this ProtectionSettings.
        The list of media types to allow for inspection, if `isResponseInspected` is enabled. Only responses with MIME types in this list will be inspected. If unspecified, defaults to `[\"text/html\", \"text/plain\", \"text/xml\"]`.

            Supported MIME types include:

            - text/html
            - text/plain
            - text/asp
            - text/css
            - text/x-script
            - application/json
            - text/webviewhtml
            - text/x-java-source
            - application/x-javascript
            - application/javascript
            - application/ecmascript
            - text/javascript
            - text/ecmascript
            - text/x-script.perl
            - text/x-script.phyton
            - application/plain
            - application/xml
            - text/xml


        :param media_types: The media_types of this ProtectionSettings.
        :type: list[str]
        """
        self._media_types = media_types

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VmNetworkDetails(object):
    """
    Details of the client or backup networks in an Exadata VM cluster network. Applies to Exadata Cloud@Customer instances only.
    """

    #: A constant which can be used with the network_type property of a VmNetworkDetails.
    #: This constant has a value of "CLIENT"
    NETWORK_TYPE_CLIENT = "CLIENT"

    #: A constant which can be used with the network_type property of a VmNetworkDetails.
    #: This constant has a value of "BACKUP"
    NETWORK_TYPE_BACKUP = "BACKUP"

    def __init__(self, **kwargs):
        """
        Initializes a new VmNetworkDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param vlan_id:
            The value to assign to the vlan_id property of this VmNetworkDetails.
        :type vlan_id: str

        :param network_type:
            The value to assign to the network_type property of this VmNetworkDetails.
            Allowed values for this property are: "CLIENT", "BACKUP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type network_type: str

        :param netmask:
            The value to assign to the netmask property of this VmNetworkDetails.
        :type netmask: str

        :param gateway:
            The value to assign to the gateway property of this VmNetworkDetails.
        :type gateway: str

        :param domain_name:
            The value to assign to the domain_name property of this VmNetworkDetails.
        :type domain_name: str

        :param nodes:
            The value to assign to the nodes property of this VmNetworkDetails.
        :type nodes: list[oci.database.models.NodeDetails]

        """
        self.swagger_types = {
            'vlan_id': 'str',
            'network_type': 'str',
            'netmask': 'str',
            'gateway': 'str',
            'domain_name': 'str',
            'nodes': 'list[NodeDetails]'
        }

        self.attribute_map = {
            'vlan_id': 'vlanId',
            'network_type': 'networkType',
            'netmask': 'netmask',
            'gateway': 'gateway',
            'domain_name': 'domainName',
            'nodes': 'nodes'
        }

        self._vlan_id = None
        self._network_type = None
        self._netmask = None
        self._gateway = None
        self._domain_name = None
        self._nodes = None

    @property
    def vlan_id(self):
        """
        **[Required]** Gets the vlan_id of this VmNetworkDetails.
        The network VLAN ID.


        :return: The vlan_id of this VmNetworkDetails.
        :rtype: str
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """
        Sets the vlan_id of this VmNetworkDetails.
        The network VLAN ID.


        :param vlan_id: The vlan_id of this VmNetworkDetails.
        :type: str
        """
        self._vlan_id = vlan_id

    @property
    def network_type(self):
        """
        **[Required]** Gets the network_type of this VmNetworkDetails.
        The network type.

        Allowed values for this property are: "CLIENT", "BACKUP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The network_type of this VmNetworkDetails.
        :rtype: str
        """
        return self._network_type

    @network_type.setter
    def network_type(self, network_type):
        """
        Sets the network_type of this VmNetworkDetails.
        The network type.


        :param network_type: The network_type of this VmNetworkDetails.
        :type: str
        """
        allowed_values = ["CLIENT", "BACKUP"]
        if not value_allowed_none_or_none_sentinel(network_type, allowed_values):
            network_type = 'UNKNOWN_ENUM_VALUE'
        self._network_type = network_type

    @property
    def netmask(self):
        """
        **[Required]** Gets the netmask of this VmNetworkDetails.
        The network netmask.


        :return: The netmask of this VmNetworkDetails.
        :rtype: str
        """
        return self._netmask

    @netmask.setter
    def netmask(self, netmask):
        """
        Sets the netmask of this VmNetworkDetails.
        The network netmask.


        :param netmask: The netmask of this VmNetworkDetails.
        :type: str
        """
        self._netmask = netmask

    @property
    def gateway(self):
        """
        **[Required]** Gets the gateway of this VmNetworkDetails.
        The network gateway.


        :return: The gateway of this VmNetworkDetails.
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """
        Sets the gateway of this VmNetworkDetails.
        The network gateway.


        :param gateway: The gateway of this VmNetworkDetails.
        :type: str
        """
        self._gateway = gateway

    @property
    def domain_name(self):
        """
        **[Required]** Gets the domain_name of this VmNetworkDetails.
        The network domain name.


        :return: The domain_name of this VmNetworkDetails.
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """
        Sets the domain_name of this VmNetworkDetails.
        The network domain name.


        :param domain_name: The domain_name of this VmNetworkDetails.
        :type: str
        """
        self._domain_name = domain_name

    @property
    def nodes(self):
        """
        **[Required]** Gets the nodes of this VmNetworkDetails.
        The list of node details.


        :return: The nodes of this VmNetworkDetails.
        :rtype: list[oci.database.models.NodeDetails]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """
        Sets the nodes of this VmNetworkDetails.
        The list of node details.


        :param nodes: The nodes of this VmNetworkDetails.
        :type: list[oci.database.models.NodeDetails]
        """
        self._nodes = nodes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreatePrivateApplicationPackage(object):
    """
    A base object for creating a private application package.
    """

    #: A constant which can be used with the package_type property of a CreatePrivateApplicationPackage.
    #: This constant has a value of "STACK"
    PACKAGE_TYPE_STACK = "STACK"

    def __init__(self, **kwargs):
        """
        Initializes a new CreatePrivateApplicationPackage object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.service_catalog.models.CreatePrivateApplicationStackPackage`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param package_type:
            The value to assign to the package_type property of this CreatePrivateApplicationPackage.
            Allowed values for this property are: "STACK"
        :type package_type: str

        :param version:
            The value to assign to the version property of this CreatePrivateApplicationPackage.
        :type version: str

        """
        self.swagger_types = {
            'package_type': 'str',
            'version': 'str'
        }

        self.attribute_map = {
            'package_type': 'packageType',
            'version': 'version'
        }

        self._package_type = None
        self._version = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['packageType']

        if type == 'STACK':
            return 'CreatePrivateApplicationStackPackage'
        else:
            return 'CreatePrivateApplicationPackage'

    @property
    def package_type(self):
        """
        **[Required]** Gets the package_type of this CreatePrivateApplicationPackage.
        The package's type.

        Allowed values for this property are: "STACK"


        :return: The package_type of this CreatePrivateApplicationPackage.
        :rtype: str
        """
        return self._package_type

    @package_type.setter
    def package_type(self, package_type):
        """
        Sets the package_type of this CreatePrivateApplicationPackage.
        The package's type.


        :param package_type: The package_type of this CreatePrivateApplicationPackage.
        :type: str
        """
        allowed_values = ["STACK"]
        if not value_allowed_none_or_none_sentinel(package_type, allowed_values):
            raise ValueError(
                "Invalid value for `package_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._package_type = package_type

    @property
    def version(self):
        """
        **[Required]** Gets the version of this CreatePrivateApplicationPackage.
        The package version.


        :return: The version of this CreatePrivateApplicationPackage.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this CreatePrivateApplicationPackage.
        The package version.


        :param version: The version of this CreatePrivateApplicationPackage.
        :type: str
        """
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApplicationSummary(object):
    """
    The model for summary of an application in service catalog.
    """

    #: A constant which can be used with the pricing_type property of a ApplicationSummary.
    #: This constant has a value of "FREE"
    PRICING_TYPE_FREE = "FREE"

    #: A constant which can be used with the pricing_type property of a ApplicationSummary.
    #: This constant has a value of "BYOL"
    PRICING_TYPE_BYOL = "BYOL"

    #: A constant which can be used with the pricing_type property of a ApplicationSummary.
    #: This constant has a value of "PAYGO"
    PRICING_TYPE_PAYGO = "PAYGO"

    #: A constant which can be used with the package_type property of a ApplicationSummary.
    #: This constant has a value of "STACK"
    PACKAGE_TYPE_STACK = "STACK"

    def __init__(self, **kwargs):
        """
        Initializes a new ApplicationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_id:
            The value to assign to the entity_id property of this ApplicationSummary.
        :type entity_id: str

        :param entity_type:
            The value to assign to the entity_type property of this ApplicationSummary.
        :type entity_type: str

        :param display_name:
            The value to assign to the display_name property of this ApplicationSummary.
        :type display_name: str

        :param is_featured:
            The value to assign to the is_featured property of this ApplicationSummary.
        :type is_featured: bool

        :param publisher:
            The value to assign to the publisher property of this ApplicationSummary.
        :type publisher: oci.service_catalog.models.PublisherSummary

        :param short_description:
            The value to assign to the short_description property of this ApplicationSummary.
        :type short_description: str

        :param logo:
            The value to assign to the logo property of this ApplicationSummary.
        :type logo: oci.service_catalog.models.UploadData

        :param pricing_type:
            The value to assign to the pricing_type property of this ApplicationSummary.
            Allowed values for this property are: "FREE", "BYOL", "PAYGO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type pricing_type: str

        :param package_type:
            The value to assign to the package_type property of this ApplicationSummary.
            Allowed values for this property are: "STACK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type package_type: str

        """
        self.swagger_types = {
            'entity_id': 'str',
            'entity_type': 'str',
            'display_name': 'str',
            'is_featured': 'bool',
            'publisher': 'PublisherSummary',
            'short_description': 'str',
            'logo': 'UploadData',
            'pricing_type': 'str',
            'package_type': 'str'
        }

        self.attribute_map = {
            'entity_id': 'entityId',
            'entity_type': 'entityType',
            'display_name': 'displayName',
            'is_featured': 'isFeatured',
            'publisher': 'publisher',
            'short_description': 'shortDescription',
            'logo': 'logo',
            'pricing_type': 'pricingType',
            'package_type': 'packageType'
        }

        self._entity_id = None
        self._entity_type = None
        self._display_name = None
        self._is_featured = None
        self._publisher = None
        self._short_description = None
        self._logo = None
        self._pricing_type = None
        self._package_type = None

    @property
    def entity_id(self):
        """
        **[Required]** Gets the entity_id of this ApplicationSummary.
        Identifier of the application from a service catalog.


        :return: The entity_id of this ApplicationSummary.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this ApplicationSummary.
        Identifier of the application from a service catalog.


        :param entity_id: The entity_id of this ApplicationSummary.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this ApplicationSummary.
        The type of an application in the service catalog.


        :return: The entity_type of this ApplicationSummary.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this ApplicationSummary.
        The type of an application in the service catalog.


        :param entity_type: The entity_type of this ApplicationSummary.
        :type: str
        """
        self._entity_type = entity_type

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ApplicationSummary.
        The name that service catalog should use to display this application.


        :return: The display_name of this ApplicationSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ApplicationSummary.
        The name that service catalog should use to display this application.


        :param display_name: The display_name of this ApplicationSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def is_featured(self):
        """
        Gets the is_featured of this ApplicationSummary.
        Indicates whether the application is featured.


        :return: The is_featured of this ApplicationSummary.
        :rtype: bool
        """
        return self._is_featured

    @is_featured.setter
    def is_featured(self, is_featured):
        """
        Sets the is_featured of this ApplicationSummary.
        Indicates whether the application is featured.


        :param is_featured: The is_featured of this ApplicationSummary.
        :type: bool
        """
        self._is_featured = is_featured

    @property
    def publisher(self):
        """
        Gets the publisher of this ApplicationSummary.

        :return: The publisher of this ApplicationSummary.
        :rtype: oci.service_catalog.models.PublisherSummary
        """
        return self._publisher

    @publisher.setter
    def publisher(self, publisher):
        """
        Sets the publisher of this ApplicationSummary.

        :param publisher: The publisher of this ApplicationSummary.
        :type: oci.service_catalog.models.PublisherSummary
        """
        self._publisher = publisher

    @property
    def short_description(self):
        """
        Gets the short_description of this ApplicationSummary.
        A short description of the application.


        :return: The short_description of this ApplicationSummary.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this ApplicationSummary.
        A short description of the application.


        :param short_description: The short_description of this ApplicationSummary.
        :type: str
        """
        self._short_description = short_description

    @property
    def logo(self):
        """
        Gets the logo of this ApplicationSummary.

        :return: The logo of this ApplicationSummary.
        :rtype: oci.service_catalog.models.UploadData
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """
        Sets the logo of this ApplicationSummary.

        :param logo: The logo of this ApplicationSummary.
        :type: oci.service_catalog.models.UploadData
        """
        self._logo = logo

    @property
    def pricing_type(self):
        """
        Gets the pricing_type of this ApplicationSummary.
        Summary of the pricing types available across all packages in the application.

        Allowed values for this property are: "FREE", "BYOL", "PAYGO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The pricing_type of this ApplicationSummary.
        :rtype: str
        """
        return self._pricing_type

    @pricing_type.setter
    def pricing_type(self, pricing_type):
        """
        Sets the pricing_type of this ApplicationSummary.
        Summary of the pricing types available across all packages in the application.


        :param pricing_type: The pricing_type of this ApplicationSummary.
        :type: str
        """
        allowed_values = ["FREE", "BYOL", "PAYGO"]
        if not value_allowed_none_or_none_sentinel(pricing_type, allowed_values):
            pricing_type = 'UNKNOWN_ENUM_VALUE'
        self._pricing_type = pricing_type

    @property
    def package_type(self):
        """
        Gets the package_type of this ApplicationSummary.
        The type of the packages withing the application.

        Allowed values for this property are: "STACK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The package_type of this ApplicationSummary.
        :rtype: str
        """
        return self._package_type

    @package_type.setter
    def package_type(self, package_type):
        """
        Sets the package_type of this ApplicationSummary.
        The type of the packages withing the application.


        :param package_type: The package_type of this ApplicationSummary.
        :type: str
        """
        allowed_values = ["STACK"]
        if not value_allowed_none_or_none_sentinel(package_type, allowed_values):
            package_type = 'UNKNOWN_ENUM_VALUE'
        self._package_type = package_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .access_request import AccessRequest
from .access_request_collection import AccessRequestCollection
from .access_request_history_collection import AccessRequestHistoryCollection
from .access_request_history_summary import AccessRequestHistorySummary
from .access_request_summary import AccessRequestSummary
from .approve_access_request_details import ApproveAccessRequestDetails
from .change_operator_control_assignment_compartment_details import ChangeOperatorControlAssignmentCompartmentDetails
from .change_operator_control_compartment_details import ChangeOperatorControlCompartmentDetails
from .create_operator_control_assignment_details import CreateOperatorControlAssignmentDetails
from .create_operator_control_details import CreateOperatorControlDetails
from .operator_action import OperatorAction
from .operator_action_collection import OperatorActionCollection
from .operator_action_properties import OperatorActionProperties
from .operator_action_summary import OperatorActionSummary
from .operator_control import OperatorControl
from .operator_control_assignment import OperatorControlAssignment
from .operator_control_assignment_collection import OperatorControlAssignmentCollection
from .operator_control_assignment_summary import OperatorControlAssignmentSummary
from .operator_control_collection import OperatorControlCollection
from .operator_control_summary import OperatorControlSummary
from .reject_access_request_details import RejectAccessRequestDetails
from .revoke_access_request_details import RevokeAccessRequestDetails
from .update_operator_control_assignment_details import UpdateOperatorControlAssignmentDetails
from .update_operator_control_details import UpdateOperatorControlDetails

# Maps type names to classes for operator_access_control services.
operator_access_control_type_mapping = {
    "AccessRequest": AccessRequest,
    "AccessRequestCollection": AccessRequestCollection,
    "AccessRequestHistoryCollection": AccessRequestHistoryCollection,
    "AccessRequestHistorySummary": AccessRequestHistorySummary,
    "AccessRequestSummary": AccessRequestSummary,
    "ApproveAccessRequestDetails": ApproveAccessRequestDetails,
    "ChangeOperatorControlAssignmentCompartmentDetails": ChangeOperatorControlAssignmentCompartmentDetails,
    "ChangeOperatorControlCompartmentDetails": ChangeOperatorControlCompartmentDetails,
    "CreateOperatorControlAssignmentDetails": CreateOperatorControlAssignmentDetails,
    "CreateOperatorControlDetails": CreateOperatorControlDetails,
    "OperatorAction": OperatorAction,
    "OperatorActionCollection": OperatorActionCollection,
    "OperatorActionProperties": OperatorActionProperties,
    "OperatorActionSummary": OperatorActionSummary,
    "OperatorControl": OperatorControl,
    "OperatorControlAssignment": OperatorControlAssignment,
    "OperatorControlAssignmentCollection": OperatorControlAssignmentCollection,
    "OperatorControlAssignmentSummary": OperatorControlAssignmentSummary,
    "OperatorControlCollection": OperatorControlCollection,
    "OperatorControlSummary": OperatorControlSummary,
    "RejectAccessRequestDetails": RejectAccessRequestDetails,
    "RevokeAccessRequestDetails": RevokeAccessRequestDetails,
    "UpdateOperatorControlAssignmentDetails": UpdateOperatorControlAssignmentDetails,
    "UpdateOperatorControlDetails": UpdateOperatorControlDetails
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .job_operation_details_summary import JobOperationDetailsSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApplyJobOperationDetailsSummary(JobOperationDetailsSummary):
    """
    Job details that are specific to apply operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApplyJobOperationDetailsSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.resource_manager.models.ApplyJobOperationDetailsSummary.operation` attribute
        of this class is ``APPLY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operation:
            The value to assign to the operation property of this ApplyJobOperationDetailsSummary.
        :type operation: str

        :param execution_plan_strategy:
            The value to assign to the execution_plan_strategy property of this ApplyJobOperationDetailsSummary.
        :type execution_plan_strategy: str

        :param execution_plan_job_id:
            The value to assign to the execution_plan_job_id property of this ApplyJobOperationDetailsSummary.
        :type execution_plan_job_id: str

        """
        self.swagger_types = {
            'operation': 'str',
            'execution_plan_strategy': 'str',
            'execution_plan_job_id': 'str'
        }

        self.attribute_map = {
            'operation': 'operation',
            'execution_plan_strategy': 'executionPlanStrategy',
            'execution_plan_job_id': 'executionPlanJobId'
        }

        self._operation = None
        self._execution_plan_strategy = None
        self._execution_plan_job_id = None
        self._operation = 'APPLY'

    @property
    def execution_plan_strategy(self):
        """
        **[Required]** Gets the execution_plan_strategy of this ApplyJobOperationDetailsSummary.
        Specifies the source of the execution plan to apply.
        Use `AUTO_APPROVED` to run the job without an execution plan.


        :return: The execution_plan_strategy of this ApplyJobOperationDetailsSummary.
        :rtype: str
        """
        return self._execution_plan_strategy

    @execution_plan_strategy.setter
    def execution_plan_strategy(self, execution_plan_strategy):
        """
        Sets the execution_plan_strategy of this ApplyJobOperationDetailsSummary.
        Specifies the source of the execution plan to apply.
        Use `AUTO_APPROVED` to run the job without an execution plan.


        :param execution_plan_strategy: The execution_plan_strategy of this ApplyJobOperationDetailsSummary.
        :type: str
        """
        self._execution_plan_strategy = execution_plan_strategy

    @property
    def execution_plan_job_id(self):
        """
        Gets the execution_plan_job_id of this ApplyJobOperationDetailsSummary.
        The `OCID`__ of the plan job that contains the execution plan used for this job,
        or `null` if no execution plan was used.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The execution_plan_job_id of this ApplyJobOperationDetailsSummary.
        :rtype: str
        """
        return self._execution_plan_job_id

    @execution_plan_job_id.setter
    def execution_plan_job_id(self, execution_plan_job_id):
        """
        Sets the execution_plan_job_id of this ApplyJobOperationDetailsSummary.
        The `OCID`__ of the plan job that contains the execution plan used for this job,
        or `null` if no execution plan was used.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param execution_plan_job_id: The execution_plan_job_id of this ApplyJobOperationDetailsSummary.
        :type: str
        """
        self._execution_plan_job_id = execution_plan_job_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BootVolumeReplica(object):
    """
    An asynchronous replica of a boot volume that can then be used to create
    a new boot volume or recover a boot volume. For more information, see `Overview
    of Cross-Region Volume Replication`__
    To use any of the API operations, you must be authorized in an IAM policy.
    If you're not authorized, talk to an administrator. If you're an administrator
    who needs to write policies to give users access, see `Getting Started with
    Policies`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you
    supply string values using the API.

    __ https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumereplication.htm
    __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a BootVolumeReplica.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a BootVolumeReplica.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a BootVolumeReplica.
    #: This constant has a value of "ACTIVATING"
    LIFECYCLE_STATE_ACTIVATING = "ACTIVATING"

    #: A constant which can be used with the lifecycle_state property of a BootVolumeReplica.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a BootVolumeReplica.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a BootVolumeReplica.
    #: This constant has a value of "FAULTY"
    LIFECYCLE_STATE_FAULTY = "FAULTY"

    def __init__(self, **kwargs):
        """
        Initializes a new BootVolumeReplica object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this BootVolumeReplica.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this BootVolumeReplica.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this BootVolumeReplica.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this BootVolumeReplica.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this BootVolumeReplica.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this BootVolumeReplica.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this BootVolumeReplica.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "ACTIVATING", "TERMINATING", "TERMINATED", "FAULTY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param size_in_gbs:
            The value to assign to the size_in_gbs property of this BootVolumeReplica.
        :type size_in_gbs: int

        :param time_created:
            The value to assign to the time_created property of this BootVolumeReplica.
        :type time_created: datetime

        :param time_last_synced:
            The value to assign to the time_last_synced property of this BootVolumeReplica.
        :type time_last_synced: datetime

        :param boot_volume_id:
            The value to assign to the boot_volume_id property of this BootVolumeReplica.
        :type boot_volume_id: str

        :param image_id:
            The value to assign to the image_id property of this BootVolumeReplica.
        :type image_id: str

        :param total_data_transferred_in_gbs:
            The value to assign to the total_data_transferred_in_gbs property of this BootVolumeReplica.
        :type total_data_transferred_in_gbs: int

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'lifecycle_state': 'str',
            'size_in_gbs': 'int',
            'time_created': 'datetime',
            'time_last_synced': 'datetime',
            'boot_volume_id': 'str',
            'image_id': 'str',
            'total_data_transferred_in_gbs': 'int'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'size_in_gbs': 'sizeInGBs',
            'time_created': 'timeCreated',
            'time_last_synced': 'timeLastSynced',
            'boot_volume_id': 'bootVolumeId',
            'image_id': 'imageId',
            'total_data_transferred_in_gbs': 'totalDataTransferredInGBs'
        }

        self._availability_domain = None
        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._lifecycle_state = None
        self._size_in_gbs = None
        self._time_created = None
        self._time_last_synced = None
        self._boot_volume_id = None
        self._image_id = None
        self._total_data_transferred_in_gbs = None

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this BootVolumeReplica.
        The availability domain of the boot volume replica.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this BootVolumeReplica.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this BootVolumeReplica.
        The availability domain of the boot volume replica.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this BootVolumeReplica.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this BootVolumeReplica.
        The OCID of the compartment that contains the boot volume replica.


        :return: The compartment_id of this BootVolumeReplica.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this BootVolumeReplica.
        The OCID of the compartment that contains the boot volume replica.


        :param compartment_id: The compartment_id of this BootVolumeReplica.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this BootVolumeReplica.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this BootVolumeReplica.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this BootVolumeReplica.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this BootVolumeReplica.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this BootVolumeReplica.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this BootVolumeReplica.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this BootVolumeReplica.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this BootVolumeReplica.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this BootVolumeReplica.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this BootVolumeReplica.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this BootVolumeReplica.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this BootVolumeReplica.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this BootVolumeReplica.
        The boot volume replica's Oracle ID (OCID).


        :return: The id of this BootVolumeReplica.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BootVolumeReplica.
        The boot volume replica's Oracle ID (OCID).


        :param id: The id of this BootVolumeReplica.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this BootVolumeReplica.
        The current state of a boot volume replica.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "ACTIVATING", "TERMINATING", "TERMINATED", "FAULTY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this BootVolumeReplica.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this BootVolumeReplica.
        The current state of a boot volume replica.


        :param lifecycle_state: The lifecycle_state of this BootVolumeReplica.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "ACTIVATING", "TERMINATING", "TERMINATED", "FAULTY"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def size_in_gbs(self):
        """
        **[Required]** Gets the size_in_gbs of this BootVolumeReplica.
        The size of the source boot volume, in GBs.


        :return: The size_in_gbs of this BootVolumeReplica.
        :rtype: int
        """
        return self._size_in_gbs

    @size_in_gbs.setter
    def size_in_gbs(self, size_in_gbs):
        """
        Sets the size_in_gbs of this BootVolumeReplica.
        The size of the source boot volume, in GBs.


        :param size_in_gbs: The size_in_gbs of this BootVolumeReplica.
        :type: int
        """
        self._size_in_gbs = size_in_gbs

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this BootVolumeReplica.
        The date and time the boot volume replica was created. Format defined
        by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this BootVolumeReplica.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this BootVolumeReplica.
        The date and time the boot volume replica was created. Format defined
        by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this BootVolumeReplica.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_last_synced(self):
        """
        **[Required]** Gets the time_last_synced of this BootVolumeReplica.
        The date and time the boot volume replica was last synced from the source boot volume.
        Format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_last_synced of this BootVolumeReplica.
        :rtype: datetime
        """
        return self._time_last_synced

    @time_last_synced.setter
    def time_last_synced(self, time_last_synced):
        """
        Sets the time_last_synced of this BootVolumeReplica.
        The date and time the boot volume replica was last synced from the source boot volume.
        Format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_last_synced: The time_last_synced of this BootVolumeReplica.
        :type: datetime
        """
        self._time_last_synced = time_last_synced

    @property
    def boot_volume_id(self):
        """
        **[Required]** Gets the boot_volume_id of this BootVolumeReplica.
        The OCID of the source boot volume.


        :return: The boot_volume_id of this BootVolumeReplica.
        :rtype: str
        """
        return self._boot_volume_id

    @boot_volume_id.setter
    def boot_volume_id(self, boot_volume_id):
        """
        Sets the boot_volume_id of this BootVolumeReplica.
        The OCID of the source boot volume.


        :param boot_volume_id: The boot_volume_id of this BootVolumeReplica.
        :type: str
        """
        self._boot_volume_id = boot_volume_id

    @property
    def image_id(self):
        """
        Gets the image_id of this BootVolumeReplica.
        The image OCID used to create the boot volume the replica is replicated from.


        :return: The image_id of this BootVolumeReplica.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """
        Sets the image_id of this BootVolumeReplica.
        The image OCID used to create the boot volume the replica is replicated from.


        :param image_id: The image_id of this BootVolumeReplica.
        :type: str
        """
        self._image_id = image_id

    @property
    def total_data_transferred_in_gbs(self):
        """
        Gets the total_data_transferred_in_gbs of this BootVolumeReplica.
        The total size of the data transferred from the source boot volume to the boot volume replica, in GBs.


        :return: The total_data_transferred_in_gbs of this BootVolumeReplica.
        :rtype: int
        """
        return self._total_data_transferred_in_gbs

    @total_data_transferred_in_gbs.setter
    def total_data_transferred_in_gbs(self, total_data_transferred_in_gbs):
        """
        Sets the total_data_transferred_in_gbs of this BootVolumeReplica.
        The total size of the data transferred from the source boot volume to the boot volume replica, in GBs.


        :param total_data_transferred_in_gbs: The total_data_transferred_in_gbs of this BootVolumeReplica.
        :type: int
        """
        self._total_data_transferred_in_gbs = total_data_transferred_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeployStageExecutionProgress(object):
    """
    Details about the execution progress of a stage in a deployment.
    """

    #: A constant which can be used with the status property of a DeployStageExecutionProgress.
    #: This constant has a value of "ACCEPTED"
    STATUS_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the status property of a DeployStageExecutionProgress.
    #: This constant has a value of "IN_PROGRESS"
    STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the status property of a DeployStageExecutionProgress.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    #: A constant which can be used with the status property of a DeployStageExecutionProgress.
    #: This constant has a value of "SUCCEEDED"
    STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the status property of a DeployStageExecutionProgress.
    #: This constant has a value of "CANCELING"
    STATUS_CANCELING = "CANCELING"

    #: A constant which can be used with the status property of a DeployStageExecutionProgress.
    #: This constant has a value of "CANCELED"
    STATUS_CANCELED = "CANCELED"

    #: A constant which can be used with the status property of a DeployStageExecutionProgress.
    #: This constant has a value of "ROLLBACK_IN_PROGRESS"
    STATUS_ROLLBACK_IN_PROGRESS = "ROLLBACK_IN_PROGRESS"

    #: A constant which can be used with the status property of a DeployStageExecutionProgress.
    #: This constant has a value of "ROLLBACK_SUCCEEDED"
    STATUS_ROLLBACK_SUCCEEDED = "ROLLBACK_SUCCEEDED"

    #: A constant which can be used with the status property of a DeployStageExecutionProgress.
    #: This constant has a value of "ROLLBACK_FAILED"
    STATUS_ROLLBACK_FAILED = "ROLLBACK_FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DeployStageExecutionProgress object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.devops.models.ComputeInstanceGroupBlueGreenTrafficShiftDeployStageExecutionProgress`
        * :class:`~oci.devops.models.ComputeInstanceGroupCanaryDeployStageExecutionProgress`
        * :class:`~oci.devops.models.ComputeInstanceGroupDeployStageExecutionProgress`
        * :class:`~oci.devops.models.LoadBalancerTrafficShiftDeployStageExecutionProgress`
        * :class:`~oci.devops.models.WaitDeployStageExecutionProgress`
        * :class:`~oci.devops.models.ComputeInstanceGroupCanaryTrafficShiftDeployStageExecutionProgress`
        * :class:`~oci.devops.models.RunValidationTestOnComputeInstanceDeployStageExecutionProgress`
        * :class:`~oci.devops.models.ManualApprovalDeployStageExecutionProgress`
        * :class:`~oci.devops.models.RunPipelineDeployStageExecutionProgress`
        * :class:`~oci.devops.models.OkeDeployStageExecutionProgress`
        * :class:`~oci.devops.models.FunctionDeployStageExecutionProgress`
        * :class:`~oci.devops.models.InvokeFunctionDeployStageExecutionProgress`
        * :class:`~oci.devops.models.ComputeInstanceGroupCanaryApprovalDeployStageExecutionProgress`
        * :class:`~oci.devops.models.ComputeInstanceGroupBlueGreenDeployStageExecutionProgress`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deploy_stage_display_name:
            The value to assign to the deploy_stage_display_name property of this DeployStageExecutionProgress.
        :type deploy_stage_display_name: str

        :param deploy_stage_type:
            The value to assign to the deploy_stage_type property of this DeployStageExecutionProgress.
        :type deploy_stage_type: str

        :param deploy_stage_id:
            The value to assign to the deploy_stage_id property of this DeployStageExecutionProgress.
        :type deploy_stage_id: str

        :param time_started:
            The value to assign to the time_started property of this DeployStageExecutionProgress.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this DeployStageExecutionProgress.
        :type time_finished: datetime

        :param status:
            The value to assign to the status property of this DeployStageExecutionProgress.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", "ROLLBACK_IN_PROGRESS", "ROLLBACK_SUCCEEDED", "ROLLBACK_FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param deploy_stage_predecessors:
            The value to assign to the deploy_stage_predecessors property of this DeployStageExecutionProgress.
        :type deploy_stage_predecessors: oci.devops.models.DeployStagePredecessorCollection

        :param deploy_stage_execution_progress_details:
            The value to assign to the deploy_stage_execution_progress_details property of this DeployStageExecutionProgress.
        :type deploy_stage_execution_progress_details: list[oci.devops.models.DeployStageExecutionProgressDetails]

        """
        self.swagger_types = {
            'deploy_stage_display_name': 'str',
            'deploy_stage_type': 'str',
            'deploy_stage_id': 'str',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'status': 'str',
            'deploy_stage_predecessors': 'DeployStagePredecessorCollection',
            'deploy_stage_execution_progress_details': 'list[DeployStageExecutionProgressDetails]'
        }

        self.attribute_map = {
            'deploy_stage_display_name': 'deployStageDisplayName',
            'deploy_stage_type': 'deployStageType',
            'deploy_stage_id': 'deployStageId',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'status': 'status',
            'deploy_stage_predecessors': 'deployStagePredecessors',
            'deploy_stage_execution_progress_details': 'deployStageExecutionProgressDetails'
        }

        self._deploy_stage_display_name = None
        self._deploy_stage_type = None
        self._deploy_stage_id = None
        self._time_started = None
        self._time_finished = None
        self._status = None
        self._deploy_stage_predecessors = None
        self._deploy_stage_execution_progress_details = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['deployStageType']

        if type == 'COMPUTE_INSTANCE_GROUP_BLUE_GREEN_TRAFFIC_SHIFT':
            return 'ComputeInstanceGroupBlueGreenTrafficShiftDeployStageExecutionProgress'

        if type == 'COMPUTE_INSTANCE_GROUP_CANARY_DEPLOYMENT':
            return 'ComputeInstanceGroupCanaryDeployStageExecutionProgress'

        if type == 'COMPUTE_INSTANCE_GROUP_ROLLING_DEPLOYMENT':
            return 'ComputeInstanceGroupDeployStageExecutionProgress'

        if type == 'LOAD_BALANCER_TRAFFIC_SHIFT':
            return 'LoadBalancerTrafficShiftDeployStageExecutionProgress'

        if type == 'WAIT':
            return 'WaitDeployStageExecutionProgress'

        if type == 'COMPUTE_INSTANCE_GROUP_CANARY_TRAFFIC_SHIFT':
            return 'ComputeInstanceGroupCanaryTrafficShiftDeployStageExecutionProgress'

        if type == 'RUN_VALIDATION_TEST_ON_COMPUTE_INSTANCE':
            return 'RunValidationTestOnComputeInstanceDeployStageExecutionProgress'

        if type == 'MANUAL_APPROVAL':
            return 'ManualApprovalDeployStageExecutionProgress'

        if type == 'RUN_DEPLOYMENT_PIPELINE':
            return 'RunPipelineDeployStageExecutionProgress'

        if type == 'OKE_DEPLOYMENT':
            return 'OkeDeployStageExecutionProgress'

        if type == 'DEPLOY_FUNCTION':
            return 'FunctionDeployStageExecutionProgress'

        if type == 'INVOKE_FUNCTION':
            return 'InvokeFunctionDeployStageExecutionProgress'

        if type == 'COMPUTE_INSTANCE_GROUP_CANARY_APPROVAL':
            return 'ComputeInstanceGroupCanaryApprovalDeployStageExecutionProgress'

        if type == 'COMPUTE_INSTANCE_GROUP_BLUE_GREEN_DEPLOYMENT':
            return 'ComputeInstanceGroupBlueGreenDeployStageExecutionProgress'
        else:
            return 'DeployStageExecutionProgress'

    @property
    def deploy_stage_display_name(self):
        """
        Gets the deploy_stage_display_name of this DeployStageExecutionProgress.
        Stage display name. Avoid entering confidential information.


        :return: The deploy_stage_display_name of this DeployStageExecutionProgress.
        :rtype: str
        """
        return self._deploy_stage_display_name

    @deploy_stage_display_name.setter
    def deploy_stage_display_name(self, deploy_stage_display_name):
        """
        Sets the deploy_stage_display_name of this DeployStageExecutionProgress.
        Stage display name. Avoid entering confidential information.


        :param deploy_stage_display_name: The deploy_stage_display_name of this DeployStageExecutionProgress.
        :type: str
        """
        self._deploy_stage_display_name = deploy_stage_display_name

    @property
    def deploy_stage_type(self):
        """
        Gets the deploy_stage_type of this DeployStageExecutionProgress.
        Deployment stage type.


        :return: The deploy_stage_type of this DeployStageExecutionProgress.
        :rtype: str
        """
        return self._deploy_stage_type

    @deploy_stage_type.setter
    def deploy_stage_type(self, deploy_stage_type):
        """
        Sets the deploy_stage_type of this DeployStageExecutionProgress.
        Deployment stage type.


        :param deploy_stage_type: The deploy_stage_type of this DeployStageExecutionProgress.
        :type: str
        """
        self._deploy_stage_type = deploy_stage_type

    @property
    def deploy_stage_id(self):
        """
        Gets the deploy_stage_id of this DeployStageExecutionProgress.
        The OCID of the stage.


        :return: The deploy_stage_id of this DeployStageExecutionProgress.
        :rtype: str
        """
        return self._deploy_stage_id

    @deploy_stage_id.setter
    def deploy_stage_id(self, deploy_stage_id):
        """
        Sets the deploy_stage_id of this DeployStageExecutionProgress.
        The OCID of the stage.


        :param deploy_stage_id: The deploy_stage_id of this DeployStageExecutionProgress.
        :type: str
        """
        self._deploy_stage_id = deploy_stage_id

    @property
    def time_started(self):
        """
        Gets the time_started of this DeployStageExecutionProgress.
        Time the stage started executing. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :return: The time_started of this DeployStageExecutionProgress.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this DeployStageExecutionProgress.
        Time the stage started executing. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :param time_started: The time_started of this DeployStageExecutionProgress.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_finished(self):
        """
        Gets the time_finished of this DeployStageExecutionProgress.
        Time the stage finished executing. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :return: The time_finished of this DeployStageExecutionProgress.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this DeployStageExecutionProgress.
        Time the stage finished executing. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :param time_finished: The time_finished of this DeployStageExecutionProgress.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def status(self):
        """
        Gets the status of this DeployStageExecutionProgress.
        The current state of the stage.

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", "ROLLBACK_IN_PROGRESS", "ROLLBACK_SUCCEEDED", "ROLLBACK_FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this DeployStageExecutionProgress.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DeployStageExecutionProgress.
        The current state of the stage.


        :param status: The status of this DeployStageExecutionProgress.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", "ROLLBACK_IN_PROGRESS", "ROLLBACK_SUCCEEDED", "ROLLBACK_FAILED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def deploy_stage_predecessors(self):
        """
        Gets the deploy_stage_predecessors of this DeployStageExecutionProgress.

        :return: The deploy_stage_predecessors of this DeployStageExecutionProgress.
        :rtype: oci.devops.models.DeployStagePredecessorCollection
        """
        return self._deploy_stage_predecessors

    @deploy_stage_predecessors.setter
    def deploy_stage_predecessors(self, deploy_stage_predecessors):
        """
        Sets the deploy_stage_predecessors of this DeployStageExecutionProgress.

        :param deploy_stage_predecessors: The deploy_stage_predecessors of this DeployStageExecutionProgress.
        :type: oci.devops.models.DeployStagePredecessorCollection
        """
        self._deploy_stage_predecessors = deploy_stage_predecessors

    @property
    def deploy_stage_execution_progress_details(self):
        """
        Gets the deploy_stage_execution_progress_details of this DeployStageExecutionProgress.
        Details about stage execution for all the target environments.


        :return: The deploy_stage_execution_progress_details of this DeployStageExecutionProgress.
        :rtype: list[oci.devops.models.DeployStageExecutionProgressDetails]
        """
        return self._deploy_stage_execution_progress_details

    @deploy_stage_execution_progress_details.setter
    def deploy_stage_execution_progress_details(self, deploy_stage_execution_progress_details):
        """
        Sets the deploy_stage_execution_progress_details of this DeployStageExecutionProgress.
        Details about stage execution for all the target environments.


        :param deploy_stage_execution_progress_details: The deploy_stage_execution_progress_details of this DeployStageExecutionProgress.
        :type: list[oci.devops.models.DeployStageExecutionProgressDetails]
        """
        self._deploy_stage_execution_progress_details = deploy_stage_execution_progress_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2018 Character Encoding Detector contributors.  https://github.com/chardet

from .mbcharsetprober import MultiByteCharSetProber
from .codingstatemachine import CodingStateMachine
from .chardistribution import EUCTWDistributionAnalysis
from .mbcssm import EUCTW_SM_MODEL

class EUCTWProber(MultiByteCharSetProber):
    def __init__(self):
        super(EUCTWProber, self).__init__()
        self.coding_sm = CodingStateMachine(EUCTW_SM_MODEL)
        self.distribution_analyzer = EUCTWDistributionAnalysis()
        self.reset()

    @property
    def charset_name(self):
        return "EUC-TW"

    @property
    def language(self):
        return "Taiwan"



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RateLimitingPolicy(object):
    """
    Limit the number of requests that should be handled for the specified window using a specfic key.
    """

    #: A constant which can be used with the rate_key property of a RateLimitingPolicy.
    #: This constant has a value of "CLIENT_IP"
    RATE_KEY_CLIENT_IP = "CLIENT_IP"

    #: A constant which can be used with the rate_key property of a RateLimitingPolicy.
    #: This constant has a value of "TOTAL"
    RATE_KEY_TOTAL = "TOTAL"

    def __init__(self, **kwargs):
        """
        Initializes a new RateLimitingPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rate_in_requests_per_second:
            The value to assign to the rate_in_requests_per_second property of this RateLimitingPolicy.
        :type rate_in_requests_per_second: int

        :param rate_key:
            The value to assign to the rate_key property of this RateLimitingPolicy.
            Allowed values for this property are: "CLIENT_IP", "TOTAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type rate_key: str

        """
        self.swagger_types = {
            'rate_in_requests_per_second': 'int',
            'rate_key': 'str'
        }

        self.attribute_map = {
            'rate_in_requests_per_second': 'rateInRequestsPerSecond',
            'rate_key': 'rateKey'
        }

        self._rate_in_requests_per_second = None
        self._rate_key = None

    @property
    def rate_in_requests_per_second(self):
        """
        **[Required]** Gets the rate_in_requests_per_second of this RateLimitingPolicy.
        The maximum number of requests per second to allow.


        :return: The rate_in_requests_per_second of this RateLimitingPolicy.
        :rtype: int
        """
        return self._rate_in_requests_per_second

    @rate_in_requests_per_second.setter
    def rate_in_requests_per_second(self, rate_in_requests_per_second):
        """
        Sets the rate_in_requests_per_second of this RateLimitingPolicy.
        The maximum number of requests per second to allow.


        :param rate_in_requests_per_second: The rate_in_requests_per_second of this RateLimitingPolicy.
        :type: int
        """
        self._rate_in_requests_per_second = rate_in_requests_per_second

    @property
    def rate_key(self):
        """
        **[Required]** Gets the rate_key of this RateLimitingPolicy.
        The key used to group requests together.

        Allowed values for this property are: "CLIENT_IP", "TOTAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The rate_key of this RateLimitingPolicy.
        :rtype: str
        """
        return self._rate_key

    @rate_key.setter
    def rate_key(self, rate_key):
        """
        Sets the rate_key of this RateLimitingPolicy.
        The key used to group requests together.


        :param rate_key: The rate_key of this RateLimitingPolicy.
        :type: str
        """
        allowed_values = ["CLIENT_IP", "TOTAL"]
        if not value_allowed_none_or_none_sentinel(rate_key, allowed_values):
            rate_key = 'UNKNOWN_ENUM_VALUE'
        self._rate_key = rate_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GiVersionSummary(object):
    """
    The Oracle Grid Infrastructure (GI) version.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GiVersionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param version:
            The value to assign to the version property of this GiVersionSummary.
        :type version: str

        """
        self.swagger_types = {
            'version': 'str'
        }

        self.attribute_map = {
            'version': 'version'
        }

        self._version = None

    @property
    def version(self):
        """
        **[Required]** Gets the version of this GiVersionSummary.
        A valid Oracle Grid Infrastructure (GI) software version.


        :return: The version of this GiVersionSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this GiVersionSummary.
        A valid Oracle Grid Infrastructure (GI) software version.


        :param version: The version of this GiVersionSummary.
        :type: str
        """
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CatalogPermissionsSummary(object):
    """
    General permissions object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CatalogPermissionsSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param catalog_id:
            The value to assign to the catalog_id property of this CatalogPermissionsSummary.
        :type catalog_id: str

        :param user_permissions:
            The value to assign to the user_permissions property of this CatalogPermissionsSummary.
        :type user_permissions: list[str]

        """
        self.swagger_types = {
            'catalog_id': 'str',
            'user_permissions': 'list[str]'
        }

        self.attribute_map = {
            'catalog_id': 'catalogId',
            'user_permissions': 'userPermissions'
        }

        self._catalog_id = None
        self._user_permissions = None

    @property
    def catalog_id(self):
        """
        Gets the catalog_id of this CatalogPermissionsSummary.
        The data catalog's OCID.


        :return: The catalog_id of this CatalogPermissionsSummary.
        :rtype: str
        """
        return self._catalog_id

    @catalog_id.setter
    def catalog_id(self, catalog_id):
        """
        Sets the catalog_id of this CatalogPermissionsSummary.
        The data catalog's OCID.


        :param catalog_id: The catalog_id of this CatalogPermissionsSummary.
        :type: str
        """
        self._catalog_id = catalog_id

    @property
    def user_permissions(self):
        """
        Gets the user_permissions of this CatalogPermissionsSummary.
        An array of permissions.


        :return: The user_permissions of this CatalogPermissionsSummary.
        :rtype: list[str]
        """
        return self._user_permissions

    @user_permissions.setter
    def user_permissions(self, user_permissions):
        """
        Sets the user_permissions of this CatalogPermissionsSummary.
        An array of permissions.


        :param user_permissions: The user_permissions of this CatalogPermissionsSummary.
        :type: list[str]
        """
        self._user_permissions = user_permissions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeliveryPolicy(object):
    """
    The subscription delivery policy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeliveryPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param backoff_retry_policy:
            The value to assign to the backoff_retry_policy property of this DeliveryPolicy.
        :type backoff_retry_policy: oci.ons.models.BackoffRetryPolicy

        """
        self.swagger_types = {
            'backoff_retry_policy': 'BackoffRetryPolicy'
        }

        self.attribute_map = {
            'backoff_retry_policy': 'backoffRetryPolicy'
        }

        self._backoff_retry_policy = None

    @property
    def backoff_retry_policy(self):
        """
        Gets the backoff_retry_policy of this DeliveryPolicy.

        :return: The backoff_retry_policy of this DeliveryPolicy.
        :rtype: oci.ons.models.BackoffRetryPolicy
        """
        return self._backoff_retry_policy

    @backoff_retry_policy.setter
    def backoff_retry_policy(self, backoff_retry_policy):
        """
        Sets the backoff_retry_policy of this DeliveryPolicy.

        :param backoff_retry_policy: The backoff_retry_policy of this DeliveryPolicy.
        :type: oci.ons.models.BackoffRetryPolicy
        """
        self._backoff_retry_policy = backoff_retry_policy

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
